==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/efs_access_point/EfsAccessPointRootDirectoryCreationInfo.java <==
package com.hashicorp.cdktf.providers.aws.efs_access_point;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:53.800Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.efsAccessPoint.EfsAccessPointRootDirectoryCreationInfo")
@software.amazon.jsii.Jsii.Proxy(EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EfsAccessPointRootDirectoryCreationInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_gid EfsAccessPoint#owner_gid}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getOwnerGid();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_uid EfsAccessPoint#owner_uid}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getOwnerUid();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#permissions EfsAccessPoint#permissions}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPermissions();

    /**
     * @return a {@link Builder} of {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EfsAccessPointRootDirectoryCreationInfo> {
        java.lang.Number ownerGid;
        java.lang.Number ownerUid;
        java.lang.String permissions;

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getOwnerGid}
         * @param ownerGid Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_gid EfsAccessPoint#owner_gid}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ownerGid(java.lang.Number ownerGid) {
            this.ownerGid = ownerGid;
            return this;
        }

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getOwnerUid}
         * @param ownerUid Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_uid EfsAccessPoint#owner_uid}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ownerUid(java.lang.Number ownerUid) {
            this.ownerUid = ownerUid;
            return this;
        }

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getPermissions}
         * @param permissions Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#permissions EfsAccessPoint#permissions}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder permissions(java.lang.String permissions) {
            this.permissions = permissions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EfsAccessPointRootDirectoryCreationInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EfsAccessPointRootDirectoryCreationInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EfsAccessPointRootDirectoryCreationInfo {
        private final java.lang.Number ownerGid;
        private final java.lang.Number ownerUid;
        private final java.lang.String permissions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ownerGid = software.amazon.jsii.Kernel.get(this, "ownerGid", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.ownerUid = software.amazon.jsii.Kernel.get(this, "ownerUid", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.permissions = software.amazon.jsii.Kernel.get(this, "permissions", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ownerGid = java.util.Objects.requireNonNull(builder.ownerGid, "ownerGid is required");
            this.ownerUid = java.util.Objects.requireNonNull(builder.ownerUid, "ownerUid is required");
            this.permissions = java.util.Objects.requireNonNull(builder.permissions, "permissions is required");
        }

        @Override
        public final java.lang.Number getOwnerGid() {
            return this.ownerGid;
        }

        @Override
        public final java.lang.Number getOwnerUid() {
            return this.ownerUid;
        }

        @Override
        public final java.lang.String getPermissions() {
            return this.permissions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ownerGid", om.valueToTree(this.getOwnerGid()));
            data.set("ownerUid", om.valueToTree(this.getOwnerUid()));
            data.set("permissions", om.valueToTree(this.getPermissions()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.efsAccessPoint.EfsAccessPointRootDirectoryCreationInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy that = (EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy) o;

            if (!ownerGid.equals(that.ownerGid)) return false;
            if (!ownerUid.equals(that.ownerUid)) return false;
            return this.permissions.equals(that.permissions);
        }

        @Override
        public final int hashCode() {
            int result = this.ownerGid.hashCode();
            result = 31 * result + (this.ownerUid.hashCode());
            result = 31 * result + (this.permissions.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/efs_access_point/EfsAccessPointRootDirectoryCreationInfo.java <==
package com.hashicorp.cdktf.providers.aws.efs_access_point;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:09.670Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.efsAccessPoint.EfsAccessPointRootDirectoryCreationInfo")
@software.amazon.jsii.Jsii.Proxy(EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EfsAccessPointRootDirectoryCreationInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#owner_gid EfsAccessPoint#owner_gid}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getOwnerGid();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#owner_uid EfsAccessPoint#owner_uid}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getOwnerUid();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#permissions EfsAccessPoint#permissions}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPermissions();

    /**
     * @return a {@link Builder} of {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EfsAccessPointRootDirectoryCreationInfo> {
        java.lang.Number ownerGid;
        java.lang.Number ownerUid;
        java.lang.String permissions;

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getOwnerGid}
         * @param ownerGid Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#owner_gid EfsAccessPoint#owner_gid}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ownerGid(java.lang.Number ownerGid) {
            this.ownerGid = ownerGid;
            return this;
        }

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getOwnerUid}
         * @param ownerUid Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#owner_uid EfsAccessPoint#owner_uid}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ownerUid(java.lang.Number ownerUid) {
            this.ownerUid = ownerUid;
            return this;
        }

        /**
         * Sets the value of {@link EfsAccessPointRootDirectoryCreationInfo#getPermissions}
         * @param permissions Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/efs_access_point#permissions EfsAccessPoint#permissions}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder permissions(java.lang.String permissions) {
            this.permissions = permissions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EfsAccessPointRootDirectoryCreationInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EfsAccessPointRootDirectoryCreationInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EfsAccessPointRootDirectoryCreationInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EfsAccessPointRootDirectoryCreationInfo {
        private final java.lang.Number ownerGid;
        private final java.lang.Number ownerUid;
        private final java.lang.String permissions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ownerGid = software.amazon.jsii.Kernel.get(this, "ownerGid", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.ownerUid = software.amazon.jsii.Kernel.get(this, "ownerUid", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.permissions = software.amazon.jsii.Kernel.get(this, "permissions", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ownerGid = java.util.Objects.requireNonNull(builder.ownerGid, "ownerGid is required");
            this.ownerUid = java.util.Objects.requireNonNull(builder.ownerUid, "ownerUid is required");
            this.permissions = java.util.Objects.requireNonNull(builder.permissions, "permissions is required");
        }

        @Override
        public final java.lang.Number getOwnerGid() {
            return this.ownerGid;
        }

        @Override
        public final java.lang.Number getOwnerUid() {
            return this.ownerUid;
        }

        @Override
        public final java.lang.String getPermissions() {
            return this.permissions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ownerGid", om.valueToTree(this.getOwnerGid()));
            data.set("ownerUid", om.valueToTree(this.getOwnerUid()));
            data.set("permissions", om.valueToTree(this.getPermissions()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.efsAccessPoint.EfsAccessPointRootDirectoryCreationInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy that = (EfsAccessPointRootDirectoryCreationInfo.Jsii$Proxy) o;

            if (!ownerGid.equals(that.ownerGid)) return false;
            if (!ownerUid.equals(that.ownerUid)) return false;
            return this.permissions.equals(that.permissions);
        }

        @Override
        public final int hashCode() {
            int result = this.ownerGid.hashCode();
            result = 31 * result + (this.ownerUid.hashCode());
            result = 31 * result + (this.permissions.hashCode());
            return result;
        }
    }
}
